@@ -1,4 +1,4 @@
-/*	$Id: Rgshhs.c 259 2013-03-30 12:53:40Z rsbivand $
+/*	$Id: Rgshhs.c 411 2022-12-12 10:14:00Z rsbivand $
  *
  *	Copyright (c) 1996-2011 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -70,7 +70,6 @@ static void swapb(void *result, int size)
 }
 
 
-SEXP Rgshhs(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 int getNpols(FILE *);
 
@@ -83,10 +82,10 @@ SEXP Rgshhs(SEXP fn, SEXP mode, SEXP dolim, SEXP lim, SEXP level, SEXP minarea)
 {
 	FILE *fp;
 	double w, e, s, n, area, lon, lat, scale = 10.0;
-	char source;
+/*	char source;*/
 	char msg[255];
 	const char *name[2] = {"polygon", "line"};
-	int k, line, max_east = 270000000, n_read, /*flip,*/ Level, version, greenwich, src, m, river;
+	int k, line, max_east = 270000000, n_read, /*flip,*/ Level, version, greenwich, src, m/*, river*/;
 	struct POINT p;
 	struct GSHHS h;
 	int npols, pc=0;
@@ -98,7 +97,7 @@ SEXP Rgshhs(SEXP fn, SEXP mode, SEXP dolim, SEXP lim, SEXP level, SEXP minarea)
 
 	fp = fopen (CHAR(STRING_ELT(fn, 0)), "rb");
 	if (fp == NULL ) {
-		sprintf(msg, "Could not find file %s", CHAR(STRING_ELT(fn, 0)));
+		snprintf(msg, sizeof(msg), "Could not find file %s", CHAR(STRING_ELT(fn, 0)));
 		error(msg);
 
 	}
@@ -179,16 +178,16 @@ SEXP Rgshhs(SEXP fn, SEXP mode, SEXP dolim, SEXP lim, SEXP level, SEXP minarea)
 		    Level = h.flag & 255;
 		    version = (h.flag >> 8) & 255;
 		    if (!(version >= 9)) 
-			error("Data not same version as software");
+			warning("Data not same version as software %d", version);
 		    greenwich = (h.flag >> 16) & 3;			/* Greenwich is 0-3 */
 		    src = (h.flag >> 24) & 1;			/* Greenwich is 0 (WDBII) or 1 (WVS) */
-		    river = (h.flag >> 25) & 1;			/* River is 0 (not river) or 1 (is river) */
+/*		    river = (h.flag >> 25) & 1;			 River is 0 (not river) or 1 (is river) */
 		    w = h.west  * GSHHS_SCL;	
 /* Convert from microdegrees to degrees */
 		    e = h.east  * GSHHS_SCL;
 		    s = h.south * GSHHS_SCL;
 		    n = h.north * GSHHS_SCL;
-		    source = (src == 1) ? 'W' : 'C';	/* Either WVS or CIA (WDBII) pedigree */
+/*		    source = (src == 1) ? 'W' : 'C';	 Either WVS or CIA (WDBII) pedigree */
 		    line = (h.area) ? 0 : 1;		/* Either Polygon (0) or Line (1) (if no area) */
 		    m = h.flag >> 26;
 		    scale = pow (10.0, (double)m);		/* Area scale */
@@ -335,7 +334,7 @@ SEXP Rgshhs(SEXP fn, SEXP mode, SEXP dolim, SEXP lim, SEXP level, SEXP minarea)
 			    if (fread ((void *)&p, 
 				(size_t) sizeof(struct POINT), 
 				(size_t) 1, fp) != 1) {
-					sprintf (msg, 
+					snprintf (msg, sizeof(msg),
 			"Error reading file %s for %s %d, point %d.\n", 
 			CHAR(STRING_ELT(fn, 0)), name[line], 
 			INTEGER_POINTER(VECTOR_ELT(res, 0))[j], k);
